==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fi\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Yhteystiedot työ"

, "Organisation / Unit"
: "Organisaatio / Osasto"

, "Business Address"
: "Työ osoite"

, "Email"
: "Sähköposti"

, "Telephone Work"
: "Työpuhelin"

, "Telephone Cellphone"
: "Matkapuhelin"

, "Telephone Car"
: "Autopuhelin"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Hakulaite"

, "URL"
: "Internetsivu"

, "Role"
: "Asema"

, "Room"
: "Huone"

, "Assistant"
: "Avustaja"

, "Assistant Telephone"
: "Avustajan puhelin"

, "Private Contact Data"
: "Yhteystiedot koti"

, "Private Address"
: "Kotiosoite"

, "Email Home"
: "Sähköposti koti"

, "Telephone Home"
: "Puhelin koti"

, "Telephone Cellphone Private"
: "Matkapuhelin koti"

, "Telephone Fax Home"
: "Fax koti"

, "URL Home"
: "Internetsivu koti"

, "Other Data"
: "Lisätiedot"

, "Birthday"
: "Syntymäpäivä"

, "Job Title"
: "Työnimike"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listat"

]
, "Percent"
: ""

, "Description"
: "Kuvaus"

, "Members"
: ""

, "Type"
: "Tyyppi"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Osoitekirja"
 ,"Osoitekirjat"

]
, "Contact, Contacts"
: [
  "Kontakti"
 ,"Kontaktit"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Maa"

, "City"
: "Toimipaikka"

, "Postalcode"
: "Postinumero"

, "Region"
: "Alue"

, "Street"
: "Osoite"

, "Street 2"
: "Osoite 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Maa (Koti)"

, "City (private)"
: "Kaupunki (yksityinen)"

, "Postalcode (private)"
: "Postinumero ( Koti)"

, "Region (private)"
: "Alue (henkilökohtainen)"

, "Street (private)"
: "Osoite (yksityinen)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Sähköpostiosoite (Koti)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Huomautukset"

, "Last Name"
: "Sukunimi"

, "Display Name"
: "Näyttönimi"

, "Full Name"
: "Koko nimi"

, "First Name"
: "Etunimi"

, "Middle Name"
: "Keski nimi"

, "Title"
: "Titteli"

, "Suffix"
: "Pääte"

, "Company"
: "Yritys"

, "Unit"
: "Yksikkö"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Työn kuvaus"

, "Salutation"
: "Tervehdys"

, "syncBackendIds"
: ""

, "Car phone"
: "Autopuhelin"

, "Mobile"
: "Matkapuhelin"

, "Mobile (private)"
: "Matkapuhelin (yksityinen)"

, "Fax"
: "Faksi"

, "Fax (private)"
: "Faksi (Yksityinen)"

, "Phone (private)"
: "Puhelin (yksityinen)"

, "Pager"
: "Hakulaite"

, "Phone"
: "Puhelin"

, "Timezone"
: "Aikavyöhyke"

, "Web"
: "WWW"

, "URL (private)"
: "Internetsivu (Koti)"

, "Label"
: ""

, "Lists"
: "Listat"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Yhteystiedot"

, "Company Address"
: "Yrityksen osoite"

, "New Contact"
: "Uusi yhteystieto"

, "ID"
: ""

, "Name"
: "Nimi"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Tuo yhteystiedot"

, "Contact of a user account"
: "Tilin yhteystieto"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Yksityinen"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Tagit"

, "List Roles"
: ""

, "Street (Company Address)"
: "Katuosoite ( Yrityksen)"

, "Street 2 (Company Address)"
: "Katuosoite 2 ( Yrityksen)"

, "City (Company Address)"
: "Kaupunki ( Yrityksen)"

, "Region (Company Address)"
: "Alue ( Yrityksen)"

, "Postal Code (Company Address)"
: "Postinumero ( Yrityksen)"

, "Country (Company Address)"
: "Maa ( Yrityksen)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Katuosoite ( Yrityksen)"

, "Street 2 (Private Address)"
: "Katuosoite 2 ( Yrityksen)"

, "City (Private Address)"
: "Kaupunki ( Yrityksen)"

, "Region (Private Address)"
: "Alue ( Yrityksen)"

, "Postal Code (Private Address)"
: "Postinumero ( Koti)"

, "Country (Private Address)"
: "Maa ( Koti)"

, "Company Communication"
: "Yritysviestintä"

, "Private Communication"
: "Yksityinen viestintä"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (yksityinen)"

, "Web (private)"
: "WWW (yksityinen)"

, "Contacts"
: "Yhteystiedot"

, "Addressbooks"
: "Osoitekirja"

, "User Account"
: "Käyttäjätili"

, "Quick Search"
: ""

, "Postal Code"
: "Postinumero"

, "Last Modified Time"
: "Viimeksi muokattu"

, "Last Modified By"
: "Viimeisin muokkaaja"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luoja"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Syötä kuvaus"

, "{0} must be given"
: ""

, "Member of List"
: "Listan jäsen"

, "Map"
: "Kartta"

, "Company address"
: "Yrityksen osoite"

, "Private address"
: "Kotiosoite"

, "CardDAV URL"
: "CardDAV Osoite"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Henkilökohtaiset tiedot"

, "Parse address"
: "Parsi osoite"

, "Print contact"
: ""

, "Paste address"
: "Liitä osoite"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Lopun merkitsemistapa"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Kaikki yhteystiedot"

, "Default Addressbook"
: "Oletus osoitekirja"

, "The default addressbook for new contacts"
: "Osoitekirja, johon uudet kontaktit lisätään"

, "Default Favorite"
: "Oletussuosikki"

, "The default favorite which is loaded on addressbook startup"
: "Oletussuosikki, joka ladataan osoitekirjan käynnistyessä"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Kontakti on jo olemassa, tarkista kentät"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Kentät tarkistetaan uutta kontaktia luotaessa. Jos vastaava merkintä on jo olemassa, annetaan virhe kaksoismerkinnästä. "

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kontaktin mahdolliset tittelit"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mahdolliset tittelit. Huomioi, että lisätyt arvot voivat näkyä väärin muissa osoitekirjaympäristöissä viennin tai synkronoinnin yhteydessä."

, "Mr"
: "Herra"

, "Ms"
: "Neiti"

, "Parsing rules for addresses"
: "Osoitteiden jäsennyssäännöt"

, "Path to a XML file with address parsing rules."
: "Polku XML-tiedostoon, joka sisältää osoitteen jäsentämissäännöt."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "VCARD Yhteystietojen tuonti"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Tuo lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "###USERFULLNAME### toi yhteystiedot  ###CURRENTDATE###  ###CURRENTTIME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 tuonti"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "CSV Outlook osoitekirjan tuonti"

, "Contact CSV import from mac address book"
: "CSV Yhteystietojen tuonti macista"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Tuo yhteystiedot gmail osoitekirjasta"

, "manage shared addressbooks"
: "hallitse jaettuja osoitekirjoja"

, "Create new shared addressbook folders"
: "Luo uusi jaettu osoitekirja kansio"

, "manage shared addressbook favorites"
: "hallinnoi jaettuja osoitekirjasuosikkeja"

, "Create or update shared addressbook favorites"
: "Luo tai muokkaa jaettuaja osoitekirjasuosikkeja"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s henkilökohtainen osoitekirja"

, "All contacts I have read grants for"
: ""

, "My company"
: "Yritykseni"

, "All coworkers in my company"
: "Työkaverini"

, "My contacts"
: "Kontaktini"

, "All contacts in my Addressbooks"
: "Kaikki kontaktit osoitekirjassani"

, "Last modified by me"
: "Viimeksi muokattu itseni toimesta"

, "All contacts that I have last modified"
: "Kaikki kontaktit joita olen viimeksi muokannut"

, "Internal Contacts"
: "Sisäiset kontaktit"

, "List"
: "Lista"

, "Addressbook"
: "Osoitekirja"

, "Contact"
: "Kontakti"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Kartta"

, "Preferred Address"
: ""

, "Personal Information"
: "Henkilökohtaiset tiedot"

, "Salutation"
: "Tervehdys"

, "Title"
: "Titteli"

, "Short Name"
: ""

, "First Name"
: "Etunimi"

, "Middle Name"
: "Keski nimi"

, "Last Name"
: "Sukunimi"

, "Company"
: "Yritys"

, "Unit"
: "Yksikkö"

, "Display Name"
: "Näyttönimi"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Työnimike"

, "Birthday (private)"
: ""

, "Contact Information"
: "Yhteystiedot"

, "Phone"
: "Puhelin"

, "Mobile"
: "Matkapuhelin"

, "Fax"
: "Faksi"

, "Phone (private)"
: "Puhelin (yksityinen)"

, "Mobile (private)"
: "Matkapuhelin (yksityinen)"

, "Fax (private)"
: "Faksi (Yksityinen)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (yksityinen)"

, "Web"
: "WWW"

, "Company Address"
: "Yrityksen osoite"

, "Street"
: "Osoite"

, "Street 2"
: "Osoite 2"

, "Region"
: "Alue"

, "Postal Code"
: "Postinumero"

, "City"
: "Toimipaikka"

, "Country"
: "Maa"

, "Private Address"
: "Kotiosoite"

, "Description"
: "Kuvaus"

, "Enter description"
: "Syötä kuvaus"

, "Groups"
: ""

, "Parse address"
: "Parsi osoite"

, "Print contact"
: ""

, "Paste address"
: "Liitä osoite"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Lopun merkitsemistapa"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Kontakti"
 ,"Kontaktit"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CardDAV Osoite"

, "New Contact"
: "Uusi yhteystieto"

, "Addressbook, Addressbooks"
: [
  "Osoitekirja"
 ,"Osoitekirjat"

]
, "ID"
: ""

, "Name"
: "Nimi"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Yksityinen"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Pääte"

, "Birthday"
: "Syntymäpäivä"

, "Job Role"
: "Työn kuvaus"

, "Room"
: "Huone"

, "Street (Company Address)"
: "Katuosoite ( Yrityksen)"

, "Street 2 (Company Address)"
: "Katuosoite 2 ( Yrityksen)"

, "City (Company Address)"
: "Kaupunki ( Yrityksen)"

, "Region (Company Address)"
: "Alue ( Yrityksen)"

, "Postal Code (Company Address)"
: "Postinumero ( Yrityksen)"

, "Country (Company Address)"
: "Maa ( Yrityksen)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Katuosoite ( Yrityksen)"

, "Street 2 (Private Address)"
: "Katuosoite 2 ( Yrityksen)"

, "City (Private Address)"
: "Kaupunki ( Yrityksen)"

, "Region (Private Address)"
: "Alue ( Yrityksen)"

, "Postal Code (Private Address)"
: "Postinumero ( Koti)"

, "Country (Private Address)"
: "Maa ( Koti)"

, "Company Communication"
: "Yritysviestintä"

, "Private Communication"
: "Yksityinen viestintä"

, "Web (private)"
: "WWW (yksityinen)"

, "Contacts"
: "Yhteystiedot"

, "Addressbooks"
: "Osoitekirja"

, "User Account"
: "Käyttäjätili"

, "Quick Search"
: ""

, "Type"
: "Tyyppi"

, "Last Modified Time"
: "Viimeksi muokattu"

, "Last Modified By"
: "Viimeisin muokkaaja"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luoja"

, "List, Lists"
: [
  "Lista"
 ,"Listat"

]
, "Lists"
: "Listat"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Tuo yhteystiedot"

, "Contact of a user account"
: "Tilin yhteystieto"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Tagit"

, "Full Name"
: "Koko nimi"

, "Postalcode"
: "Postinumero"

, "Street (private)"
: "Osoite (yksityinen)"

, "City (private)"
: "Kaupunki (yksityinen)"

, "Region (private)"
: "Alue (henkilökohtainen)"

, "Postalcode (private)"
: "Postinumero ( Koti)"

, "Country (private)"
: "Maa (Koti)"

, "Email"
: "Sähköposti"

, "Car phone"
: "Autopuhelin"

, "Pager"
: "Hakulaite"

, "Email (private)"
: "Sähköpostiosoite (Koti)"

, "URL (private)"
: "Internetsivu (Koti)"

, "Note"
: "Huomautukset"

, "Timezone"
: "Aikavyöhyke"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Yrityksen osoite"

, "Private address"
: "Kotiosoite"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Kaikki yhteystiedot"

, "Default Addressbook"
: "Oletus osoitekirja"

, "The default addressbook for new contacts"
: "Osoitekirja, johon uudet kontaktit lisätään"

, "Default Favorite"
: "Oletussuosikki"

, "The default favorite which is loaded on addressbook startup"
: "Oletussuosikki, joka ladataan osoitekirjan käynnistyessä"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Kontakti on jo olemassa, tarkista kentät"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Kentät tarkistetaan uutta kontaktia luotaessa. Jos vastaava merkintä on jo olemassa, annetaan virhe kaksoismerkinnästä. "

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kontaktin mahdolliset tittelit"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mahdolliset tittelit. Huomioi, että lisätyt arvot voivat näkyä väärin muissa osoitekirjaympäristöissä viennin tai synkronoinnin yhteydessä."

, "Mr"
: "Herra"

, "Ms"
: "Neiti"

, "Parsing rules for addresses"
: "Osoitteiden jäsennyssäännöt"

, "Path to a XML file with address parsing rules."
: "Polku XML-tiedostoon, joka sisältää osoitteen jäsentämissäännöt."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s henkilökohtainen osoitekirja"

, "Business Contact Data"
: "Yhteystiedot työ"

, "Organisation / Unit"
: "Organisaatio / Osasto"

, "Business Address"
: "Työ osoite"

, "Telephone Work"
: "Työpuhelin"

, "Telephone Cellphone"
: "Matkapuhelin"

, "Telephone Car"
: "Autopuhelin"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Hakulaite"

, "URL"
: "Internetsivu"

, "Role"
: "Asema"

, "Assistant"
: "Avustaja"

, "Assistant Telephone"
: "Avustajan puhelin"

, "Private Contact Data"
: "Yhteystiedot koti"

, "Email Home"
: "Sähköposti koti"

, "Telephone Home"
: "Puhelin koti"

, "Telephone Cellphone Private"
: "Matkapuhelin koti"

, "Telephone Fax Home"
: "Fax koti"

, "URL Home"
: "Internetsivu koti"

, "Other Data"
: "Lisätiedot"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "CSV Outlook osoitekirjan tuonti"

, "Contact CSV import from mac address book"
: "CSV Yhteystietojen tuonti macista"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 tuonti"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "VCARD Yhteystietojen tuonti"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Tuo lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "###USERFULLNAME### toi yhteystiedot  ###CURRENTDATE###  ###CURRENTTIME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Tuo yhteystiedot gmail osoitekirjasta"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Sisäiset kontaktit"

, "All contacts I have read grants for"
: ""

, "My company"
: "Yritykseni"

, "All coworkers in my company"
: "Työkaverini"

, "My contacts"
: "Kontaktini"

, "All contacts in my Addressbooks"
: "Kaikki kontaktit osoitekirjassani"

, "Last modified by me"
: "Viimeksi muokattu itseni toimesta"

, "All contacts that I have last modified"
: "Kaikki kontaktit joita olen viimeksi muokannut"

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "hallitse jaettuja osoitekirjoja"

, "Create new shared addressbook folders"
: "Luo uusi jaettu osoitekirja kansio"

, "manage shared addressbook favorites"
: "hallinnoi jaettuja osoitekirjasuosikkeja"

, "Create or update shared addressbook favorites"
: "Luo tai muokkaa jaettuaja osoitekirjasuosikkeja"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Kontakti"

, "Addressbook"
: "Osoitekirja"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Lista"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
